Attribute VB_Name = "DXF_TestMakro1"
' **********************************************************************
' * Makro erzeugt aus dem aktiven Zeichnungsdokument fr alle Bltter
' * eine DXF Datei im Unterverzeichnis DXF der Zeichnung. Es werden alle
' * Bltter unter dem Namen kombiniert mit dem Blattnamen abgespeichert.
' *
' * Basiert auf einer Vorlage von:
' * Vorlage
' * 05.04.2001 Stefan Berlitz (stefan.berlitz@solidworks.cad.de)
' * http://solidworks.cad.de
' * http://swtools.cad.de
' * Gendert fr einen DXF import von DIN1031 - 24.04.2013
' **********************************************************************
Option Explicit

Dim swApp               As SldWorks.SldWorks
Dim swDrawingDoc        As SldWorks.ModelDoc2
Dim swSheet             As SldWorks.Sheet
Dim swModelDocExt       As SldWorks.ModelDocExtension
Dim swPs                As SldWorks.PageSetup

Dim bShowMap            As Boolean
Dim bReturn             As Boolean
Dim bCollate            As Boolean

Dim vSheets             As Variant
Dim vSheetProps         As Variant
Dim vPageArray          As Variant

Dim strDateiname        As String
Dim strDXFDateiname     As String
Dim strDateinameLang    As String
Dim strPfad             As String
Dim strDXFPfad          As String
Dim strMsgtxt           As String
Dim strSheetName        As String
Dim strPrinter          As String

Dim i                   As Long
Dim lAnzahlBl           As Long
Dim lErrors             As Long
Dim lWarnings           As Long
Dim lFarbe              As Long
Dim lPageArray          As Long
Dim lCopies             As Long


Dim intReturn           As Integer



Sub main()
    
    'Anbindung an SWX
    Set swApp = Application.SldWorks
    Set swDrawingDoc = swApp.ActiveDoc
    strMsgtxt = ""
    
    ' wenn keine Zeichnung aktiv wird das Makro wieder beendet
    If (swDrawingDoc.GetType <> swDocDRAWING) Then
        MsgBox "Nur fr Zeichnungen geeignet"
        Exit Sub
    End If
    
    ' Prfung, ob Zeichnung gespeichert werden muss. Falls Zeichnung nicht
    ' gespeichert wird, Abbruch!
    If swDrawingDoc.GetSaveFlag Then
        intReturn = swApp.SendMsgToUser2("Soll die Zeichnung gesichert werden?", swMbQuestion, swMbYesNo)
        If intReturn = swMbHitYes Then
            bReturn = swDrawingDoc.Save3(swSaveAsOptions_Silent, lErrors, lWarnings)
        Else
            intReturn = swApp.SendMsgToUser2("Bitte die Zeichnung speichern!", swMbInformation, swMbOk)
            Exit Sub
        End If
    End If
    
    ' die Anzahl der Bltter holen, und dann in der Schleife eines nach
    ' dem anderen Abspeichern. Dazu ein Handle auf das aktuelle Blatt holen
    lAnzahlBl = swDrawingDoc.GetSheetCount
    Set swSheet = swDrawingDoc.GetCurrentSheet
    
    ' damit die PDF anschlieend im Unterverzeichnis PDF der Zeichnung gespeichert
    ' werden, muss der Pfad ermittelt werden.
    strDateinameLang = swDrawingDoc.GetPathName
    
    ' Zerlegen in Pfad und Dateiname ohne Extension (7 Zeichen)
    For i = Len(strDateinameLang) To 1 Step -1
        If Mid(strDateinameLang, i, 1) = "\" Then
            strPfad = Left(strDateinameLang, i)
            strDateiname = Mid(strDateinameLang, i + 1, Len(strDateinameLang) - i - 7)
            Exit For
        End If
    Next i
    
    ' PDF-Dateien sollen im Unterverzeichnis PDF abgespeichert werden;
    strDXFPfad = strPfad + "DXF\"
    
    ' Prfung, ob die Verzeichnisse berhaupt existiert, da sie sonst angelegt
    ' werden mssen
    If Len(Dir(strDXFPfad, vbDirectory)) = 0 Then
        MkDir (strDXFPfad)
    End If
    
    ' wenn mehr als ein Blatt da ist knnte es sein, dass wir nicht auf
    ' Blatt 1 sind. In einem Makro mssen wir jetzt einen Trick machen, um
    ' auf das erste Blatt zurckzukommen.
    ' Dazu immer wieder ein Blatt zurckspringen und dabei den Blattnamen
    ' vergleichen; wenn der gleich bleibt haben wir das erste Blatt erreicht.
    strSheetName = swSheet.GetName
    For i = 1 To lAnzahlBl - 1
        swDrawingDoc.SheetPrevious
        Set swSheet = swDrawingDoc.GetCurrentSheet
        If (strSheetName = swSheet.GetName) Then
            Exit For
        End If
    Next i
        
    ' jetzt sind wir garantiert auf dem ersten Blatt und knnen jetzt eins
    ' nach dem anderen Abspeichern
    For i = 1 To lAnzahlBl
        
        ' wir wollen alle Bltter als DXF mit den eingestellten Optionen abspeichern
        Set swSheet = swDrawingDoc.GetCurrentSheet
        strSheetName = swSheet.GetName
        strDXFDateiname = strDXFPfad & strDateiname & " (" & strSheetName & ").dxf"
        
        ' dann erfolgt das Speichern als PDF mittels swModelDocExt.SaveAs
        ' wenn alles geklappt hat, wird TRUE zurckgeliefert, ansonsten FALSE
        
        Set swModelDocExt = swDrawingDoc.Extension
        bShowMap = swApp.GetUserPreferenceToggle(swDXFDontShowMap)
        swApp.SetUserPreferenceToggle swDXFDontShowMap, False
 
        bReturn = swDrawingDoc.SaveAs4(strDXFDateiname, swSaveAsCurrentVersion, swSaveAsOptions_Copy, _
                     lErrors, lWarnings)
        
        If bReturn Then
            strMsgtxt = strMsgtxt & "erfolgreich gespeichert: " & strDateiname & " (" & strSheetName & ")" & _
                     ".dxf" & Chr$(10) & Chr$(13)
        Else
            intReturn = swApp.SendMsgToUser2("FEHLER BEIM SPEICHERN VON " & strDateiname & " (" & strSheetName & ")" & _
                   ".dxf" & Chr$(10) & Chr$(13), swMbInformation, swMbOk)
            strMsgtxt = strMsgtxt & "*** FEHLER bei: " & strDateiname & " (" & strSheetName & ")" & _
                     ".dxf" & Chr$(10) & Chr$(13)
        End If
        
        swApp.SetUserPreferenceToggle swDXFDontShowMap, bShowMap
        
        ' und wenn noch Bltter kommen dieses aktivieren
        If lAnzahlBl > i Then
            swDrawingDoc.SheetNext
        End If
    Next i
    
    ' und noch die Zusammenfassung bers Speichern ausgeben
    intReturn = swApp.SendMsgToUser2(strMsgtxt, swMbInformation, swMbOk)
    
End Sub

